@@ -1,15 +1,10 @@
 # -*- coding: utf-8 -*-
 
-import requests
 import tideway
 
 dr = tideway.discoRequests
 appliance = tideway.main.Appliance
 
-# class Test:
-#     def __init__(self):
-#         self.help = "Help!"
-
 class Admin(appliance):
     '''Manage the BMC Discovery appliance.'''
 
@@ -17,11 +12,13 @@ class Admin(appliance):
         '''Get a summary of the appliance status, and details of which baseline checks have passed or failed.'''
         response = dr.discoRequest(self, "/admin/baseline")
         return response
+    get_admin_baseline = property(baseline)
 
     def admin(self):
         '''Get information about the appliance, like its version and versions of the installed packages.'''
         response = dr.discoRequest(self, "/admin/about")
         return response
+    get_admin_about = property(admin)
 
     def licensing(self,content_type="text/plain"):
         '''Get the latest signed licensing report.'''
