@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import requests
 import tideway
 
 dr = tideway.discoRequests
@@ -9,6 +8,11 @@ appliance = tideway.main.Appliance
 class Events(appliance):
     '''Push events.'''
 
+    def post_events(self, body):
+        '''An alternate API call for POST /events'''
+        response = dr.discoPost(self, "/events", body)
+        return response
+
     def status(self, body):
         '''
             Returns a unique ID if the event has been recorded, otherwise an
